# Contributing Guide 🤝

Thanks for being interested in contributing to this project!

Before submitting any contribution, please make sure to read the following guidelines:

- [Reporting Issues](#reporting-issues-)
- [Feature Requests](#feature-requests-)
- [Pull Requests](#pull-requests-)
- [Development Setup](#development-setup-)
- [Questions & Help](#questions--help-)

## Reporting Issues 🚨

A great way to contribute to the project is to send a detailed report if you find an issue.

[Bug report →](https://github.com/ivodolenc/aspekta/issues/new/choose)

## Feature Requests 🚀

Feel free to suggest a new idea or a quick enhancement that you would love to see.

Before you create a feature request, it's polite to `leave a star`. It means a lot and gives motivation for further development.

[Feature request →](https://github.com/ivodolenc/aspekta/issues/new/choose)

## Pull Requests 🔀

Before you create a pull request, first open a `Bug report` or `Feature request` so that it can be discussed and approved.

Please keep in mind that pull requests without discussion will not be considered for merging.

[Pull request →](https://github.com/ivodolenc/aspekta/pulls)

## Development Setup 💻

This quick guides is intended for intermediate or advanced users who are familiar with Git workflow and font development.

### Required Stack

- [Git](https://github.com/git-guides)
- [Glyphs](https://glyphsapp.com/)

### Get Started

1. Download and install all **required stack**.
2. Fork the **aspekta** repository on Github.
3. [Clone](https://github.com/git-guides/git-clone) your **fork** to the local workspace.
4. Create a new **branch** via git:

```sh
git checkout -b <branch-name>
```

5. Start working on your changes.
6. When you ready to publish new changes, [add](https://github.com/git-guides/git-add) them to the staging area:

```sh
git add .
```

7. Create a new [commit](https://github.com/git-guides/git-commit):

```sh
git commit -m "feat: add new glyphs"
```

8. [Push](https://github.com/git-guides/git-push) commit to your forked repository:

```sh
git push origin <branch-name>
```

9. Open a [Pull request](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/creating-a-pull-request-from-a-fork) with your new changes.

That's it! Start developing!

If you have additional questions, feel free to create a new discussion.

## Questions & Help 🙋

Official forum is the best place to ask for help or discuss all questions related to this project.

[Visit Discussions →](https://github.com/ivodolenc/aspekta/discussions)
